@@ -1,7 +1,6 @@
-/* Copyright Abandoned 1996,1999 TCX DataKonsult AB & Monty Program KB
-   & Detron HB, 1996, 1999-2004, 2007 MySQL AB.
-   This file is public domain and comes with NO WARRANTY of any kind
-*/
+/* Copyright (c) 1996, 1999-2004, 2007 MySQL AB
+   Use is subject to license terms
+   This file is public domain and comes with NO WARRANTY of any kind */
 
 /* Version numbers for protocol & mysqld */
 
@@ -11,11 +10,11 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MYSQL_SERVER_VERSION		"5.5.59"
-#define MYSQL_BASE_VERSION		"mysqld-5.5"
+#define MYSQL_SERVER_VERSION		"5.6.12"
+#define MYSQL_BASE_VERSION		"mysqld-5.6"
 #define MYSQL_SERVER_SUFFIX_DEF		""
 #define FRM_VER				6
-#define MYSQL_VERSION_ID		50559
+#define MYSQL_VERSION_ID		50612
 #define MYSQL_PORT			3306
 #define MYSQL_PORT_DEFAULT		0
 #define MYSQL_UNIX_ADDR			"/tmp/mysql.sock"
